drawColor method

  1. @override
void drawColor(
  1. Color color,
  2. BlendMode blendMode
)
override

Paints the given Color onto the canvas, applying the given BlendMode, with the given color being the source and the background being the destination.

Implementation

@override
void drawColor(ui.Color color, ui.BlendMode blendMode) =>
    parent.drawColor(color, blendMode);