drawImage method
Draws the given Image into the canvas with its top-left corner at the given Offset. The image is composited into the canvas using the given Paint.
Implementation
@override
void drawImage(ui.Image image, ui.Offset offset, ui.Paint paint) =>
parent.drawImage(image, offset, paint);